@@ -269,9 +269,8 @@ sub Sync {
         # add new user
         if ( %SyncUser && !$UserID ) {
             $UserID = $UserObject->UserAdd(
-                UserTitle => 'Mr/Mrs',
                 UserLogin => $Param{User},
-                %SyncUser,
+                %SyncUser,    # Must contain other parameters required by UserAdd.
                 UserType     => 'User',
                 ValidID      => 1,
                 ChangeUserID => 1,
@@ -335,17 +334,21 @@ sub Sync {
             my $AttributeChange;
             ATTRIBUTE:
             for my $Attribute ( sort keys %SyncUser ) {
-                next ATTRIBUTE if defined $SyncUser{$Attribute} && $SyncUser{$Attribute} eq $UserData{$Attribute};
+
+                # Treat undef and empty strings as equal.
+                my $SyncUserAttribute = $SyncUser{$Attribute} // '';
+                my $UserDataAttribute = $UserData{$Attribute} // '';
+                next ATTRIBUTE if $SyncUserAttribute eq $UserDataAttribute;
                 $AttributeChange = 1;
                 last ATTRIBUTE;
             }
 
             if ($AttributeChange) {
                 $UserObject->UserUpdate(
-                    %UserData,
+                    ValidID   => $UserData{ValidID},    # May be not present in %SyncUser and is required by UserUpdate.
                     UserID    => $UserID,
                     UserLogin => $Param{User},
-                    %SyncUser,
+                    %SyncUser,                          # Must contain other parameters required by UserUpdate.
                     UserType     => 'User',
                     ChangeUserID => 1,
                 );
