@@ -361,7 +361,7 @@ sub CustomerSearch {
                     $SQLExt .= " LOWER($Field) = LOWER(?) ";
                 }
             }
-            $SQL .= $SQLExt;
+            $SQL .= " ($SQLExt) ";
         }
     }
     elsif ( $Param{UserLogin} ) {
