@@ -5,7 +5,6 @@
 # the enclosed file COPYING for license information (AGPL). If you
 # did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
-## nofilter(TidyAll::Plugin::OTRS::Perl::Pod::SpellCheck)
 
 package Kernel::System::DynamicField::Webservice;
 
@@ -153,6 +152,7 @@ sub Test {
             $Data->{DisplayValue} = $DisplayValue;
         }
     }
+
     $Result->{Search}          = $Self->{Search};
     $Result->{Data}            = $Results;
     $Result->{StoredValue}     = \@StoredValue;
@@ -993,7 +993,6 @@ sub _DisplayValueAssemble {
     if ( !defined $BackendConfig->{DisplayedValues} || !length $BackendConfig->{DisplayedValues} ) {
         $DisplayKeyValuesConfig = $BackendConfig->{StoredValue};
     }
-
     return if !$DisplayKeyValuesConfig;
 
     my @DisplayKeyValues = split /\s*,\s*/, $DisplayKeyValuesConfig;
@@ -1040,8 +1039,10 @@ This function is only needed for WebserviceMultiselect (multiselect).
 
     my $Value = $DynamicFieldWebserviceObject->Template(
         DynamicFieldConfig => \%DynamicFieldConfig,
-        Value              => ['first','second', 'third'],
-        ContentType        => 'ASCII', # HTML is default
+        Value              => ['first','second', 'third'], # or a scalar value
+        Type               => 'Value', # optional; or 'Title'
+        ContentType        => 'ASCII', # optional; 'HTML' is default,
+        TemplateType       => 'default', # optional; or: 'separator', 'wordwrap', 'list'
     );
 
 Returns:
@@ -1104,8 +1105,10 @@ sub Template {
     my $TemplateType = $Param{DynamicFieldConfig}->{Config}->{TemplateType} || 'default';
 
     if ( $Param{LayoutObject}->{Action} && $Param{Type} ) {
-        $ContentType  = $ActionTemplateMap{ $Param{LayoutObject}->{Action} }->{ $Param{Type} }->{ContentType};
-        $TemplateType = $ActionTemplateMap{ $Param{LayoutObject}->{Action} }->{ $Param{Type} }->{TemplateType};
+        $ContentType
+            = $ActionTemplateMap{ $Param{LayoutObject}->{Action} }->{ $Param{Type} }->{ContentType} || $ContentType;
+        $TemplateType
+            = $ActionTemplateMap{ $Param{LayoutObject}->{Action} }->{ $Param{Type} }->{TemplateType} || $TemplateType;
     }
 
     if ( $Param{ContentType} ) {
@@ -1313,7 +1316,7 @@ sub _BackendConfigGet {
     my %DefaultValues = (
         Backend         => 'DirectRequest',
         StoredValue     => 'Key',
-        DisplayedValues => 'Value',
+        DisplayedValues => '',
         DefaultValue    => '',
         Link            => '',
     );
