@@ -105,7 +105,7 @@ our %DistToInstType = (
 
 our $OSDist;
 eval {
-    require Linux::Distribution;    ## nofilter(TidyAll::Plugin::OTRS::Perl::Require)
+    require Linux::Distribution;    ## nofilter(TidyAll::Plugin::Znuny::Perl::Require)
     import Linux::Distribution;
     $OSDist = Linux::Distribution::distribution_name() || '';
 };
@@ -224,7 +224,7 @@ my @NeededModules = (
         Required  => 0,
         Comment   => 'X509 certificate support.',
         InstTypes => {
-            aptget => 'libcrypt-openssl-x509',
+            aptget => 'libcrypt-openssl-x509-perl',
             emerge => 'dev-perl/Crypt-OpenSSL-X509',
             zypper => 'perl-Crypt-OpenSSL-X509',
             ports  => 'security/p5-Crypt-OpenSSL-X509',
@@ -394,6 +394,17 @@ my @NeededModules = (
             ports  => 'textproc/p5-Hash-Merge',
         },
     },
+    {
+        Module    => 'iCal::Parser',
+        Required  => 1,
+        Comment   => 'Required for calendar events.',
+        InstTypes => {
+            aptget => 'libical-parser-perl',
+            emerge => 'perl-core/iCal-Parser',
+            zypper => 'perl-iCal-Parser',
+            ports  => 'devel/p5-iCal-Parser',
+        },
+    },
     {
         Module              => 'IO::Socket::SSL',
         Required            => 0,
@@ -652,6 +663,17 @@ my @NeededModules = (
             ports  => 'devel/p5-Time-HiRes',
         },
     },
+    {
+        Module    => 'Time::Piece',
+        Required  => 1,
+        Comment   => 'Required for calendar events.',
+        InstTypes => {
+            aptget => 'libtime-piece-perl',
+            emerge => 'perl-core/Time-Piece',
+            zypper => 'perl-Time-Piece',
+            ports  => 'devel/p5-Time-Piece',
+        },
+    },
     {
         Module    => 'XML::LibXML',
         Required  => 1,
